 dpkg-buildpackage -rfakeroot -us -uc
dpkg-buildpackage: warning: using a gain-root-command while being root
dpkg-buildpackage: info: source package librb
dpkg-buildpackage: info: source version 1.0.0
dpkg-buildpackage: info: source distribution stretch
dpkg-buildpackage: info: source changed by Michał Łyszczek <michal.lyszczek@bofc.pl>
 dpkg-source --before-build librb
dpkg-buildpackage: info: host architecture amd64
 fakeroot debian/rules clean
dh clean --list-missing --with autoreconf
   dh_testdir -O--list-missing
   dh_auto_clean -O--list-missing
   dh_autoreconf_clean -O--list-missing
   dh_clean -O--list-missing
	rm -f debian/debhelper-build-stamp
	rm -f debian/librb1.substvars
	rm -f debian/librb1.*.debhelper
	rm -rf debian/librb1/
	rm -f debian/librb-dev.substvars
	rm -f debian/librb-dev.*.debhelper
	rm -rf debian/librb-dev/
	rm -rf debian/.debhelper/
	rm -f debian/*.debhelper.log
	rm -f debian/files
	find .  \( \( \
		\( -path .\*/.git -o -path .\*/.svn -o -path .\*/.bzr -o -path .\*/.hg -o -path .\*/CVS \) -prune -o -type f -a \
	        \( -name '#*#' -o -name '.*~' -o -name '*~' -o -name DEADJOE \
		 -o -name '*.orig' -o -name '*.rej' -o -name '*.bak' \
		 -o -name '.*.orig' -o -name .*.rej -o -name '.SUMS' \
		 -o -name TAGS -o \( -path '*/.deps/*' -a -name '*.P' \) \
		\) -exec rm -f {} + \) -o \
		\( -type d -a -name autom4te.cache -prune -exec rm -rf {} + \) \)
	rm -f *-stamp
 dpkg-source -b librb
dpkg-source: info: using source format '3.0 (native)'
dpkg-source: info: building librb in librb_1.0.0.tar.xz
dpkg-source: info: building librb in librb_1.0.0.dsc
 debian/rules build
dh build --list-missing --with autoreconf
   dh_testdir -O--list-missing
   dh_update_autotools_config -O--list-missing
   dh_autoreconf -O--list-missing
	find ! -ipath "./debian/*" -a ! \( -path '*/.git/*' -o -path '*/.hg/*' -o -path '*/.bzr/*' -o -path '*/.svn/*' -o -path '*/CVS/*' \) -a  -type f -exec md5sum {} + > debian/autoreconf.before
	autoreconf -f -i
libtoolize: putting auxiliary files in '.'.
libtoolize: copying file './ltmain.sh'
libtoolize: putting macros in AC_CONFIG_MACRO_DIRS, 'm4'.
libtoolize: copying file 'm4/libtool.m4'
libtoolize: copying file 'm4/ltoptions.m4'
libtoolize: copying file 'm4/ltsugar.m4'
libtoolize: copying file 'm4/ltversion.m4'
libtoolize: copying file 'm4/lt~obsolete.m4'
configure.ac:3: installing './compile'
configure.ac:4: installing './config.guess'
configure.ac:4: installing './config.sub'
configure.ac:2: installing './install-sh'
configure.ac:2: installing './missing'
rb/Makefile.am: installing './depcomp'
parallel-tests: installing './test-driver'
	find ! -ipath "./debian/*" -a ! \( -path '*/.git/*' -o -path '*/.hg/*' -o -path '*/.bzr/*' -o -path '*/.svn/*' -o -path '*/CVS/*' \) -a  -type f -exec md5sum {} + > debian/autoreconf.after
   dh_auto_configure -O--list-missing
	./configure --build=x86_64-linux-gnu --prefix=/usr --includedir=\${prefix}/include --mandir=\${prefix}/share/man --infodir=\${prefix}/share/info --sysconfdir=/etc --localstatedir=/var --disable-silent-rules --libdir=\${prefix}/lib/x86_64-linux-gnu --libexecdir=\${prefix}/lib/x86_64-linux-gnu --disable-maintainer-mode --disable-dependency-tracking
configure: WARNING: unrecognized options: --disable-maintainer-mode
checking for a BSD-compatible install... /usr/bin/install -c
checking whether build environment is sane... yes
checking for a thread-safe mkdir -p... /bin/mkdir -p
checking for gawk... no
checking for mawk... mawk
checking whether make sets $(MAKE)... yes
checking whether make supports nested variables... yes
checking for gcc... gcc
checking whether the C compiler works... yes
checking for C compiler default output file name... a.out
checking for suffix of executables... 
checking whether we are cross compiling... no
checking for suffix of object files... o
checking whether we are using the GNU C compiler... yes
checking whether gcc accepts -g... yes
checking for gcc option to accept ISO C89... none needed
checking whether gcc understands -c and -o together... yes
checking for style of include used by make... GNU
checking dependency style of gcc... none
checking build system type... x86_64-pc-linux-gnu
checking host system type... x86_64-pc-linux-gnu
checking how to print strings... printf
checking for a sed that does not truncate output... /bin/sed
checking for grep that handles long lines and -e... /bin/grep
checking for egrep... /bin/grep -E
checking for fgrep... /bin/grep -F
checking for ld used by gcc... /usr/bin/ld
checking if the linker (/usr/bin/ld) is GNU ld... yes
checking for BSD- or MS-compatible name lister (nm)... /usr/bin/nm -B
checking the name lister (/usr/bin/nm -B) interface... BSD nm
checking whether ln -s works... yes
checking the maximum length of command line arguments... 1572864
checking how to convert x86_64-pc-linux-gnu file names to x86_64-pc-linux-gnu format... func_convert_file_noop
checking how to convert x86_64-pc-linux-gnu file names to toolchain format... func_convert_file_noop
checking for /usr/bin/ld option to reload object files... -r
checking for objdump... objdump
checking how to recognize dependent libraries... pass_all
checking for dlltool... no
checking how to associate runtime and link libraries... printf %s\n
checking for ar... ar
checking for archiver @FILE support... @
checking for strip... strip
checking for ranlib... ranlib
checking command to parse /usr/bin/nm -B output from gcc object... ok
checking for sysroot... no
checking for a working dd... /bin/dd
checking how to truncate binary pipes... /bin/dd bs=4096 count=1
checking for mt... mt
checking if mt is a manifest tool... no
checking how to run the C preprocessor... gcc -E
checking for ANSI C header files... yes
checking for sys/types.h... yes
checking for sys/stat.h... yes
checking for stdlib.h... yes
checking for string.h... yes
checking for memory.h... yes
checking for strings.h... yes
checking for inttypes.h... yes
checking for stdint.h... yes
checking for unistd.h... yes
checking for dlfcn.h... yes
checking for objdir... .libs
checking if gcc supports -fno-rtti -fno-exceptions... no
checking for gcc option to produce PIC... -fPIC -DPIC
checking if gcc PIC flag -fPIC -DPIC works... yes
checking if gcc static flag -static works... yes
checking if gcc supports -c -o file.o... yes
checking if gcc supports -c -o file.o... (cached) yes
checking whether the gcc linker (/usr/bin/ld -m elf_x86_64) supports shared libraries... yes
checking whether -lc should be explicitly linked in... no
checking dynamic linker characteristics... GNU/Linux ld.so
checking how to hardcode library paths into programs... immediate
checking whether stripping libraries is possible... yes
checking if libtool supports shared libraries... yes
checking whether to build shared libraries... yes
checking whether to build static libraries... yes
checking whether gcc is Clang... no
checking whether pthreads work with -pthread... yes
checking for joinable pthread attribute... PTHREAD_CREATE_JOINABLE
checking whether more special flags are required for pthreads... no
checking for PTHREAD_PRIO_INHERIT... yes
checking that generated files are newer than configure... done
configure: creating ./config.status
config.status: creating Makefile
config.status: creating rb/Makefile
config.status: creating include/Makefile
config.status: creating man/Makefile
config.status: creating www/Makefile
config.status: creating config.h
config.status: executing depfiles commands
config.status: executing libtool commands
configure: WARNING: unrecognized options: --disable-maintainer-mode
   dh_auto_build -O--list-missing
	make -j1
make[1]: Entering directory '/tmp/librb-v1.0.0-r1/librb'
make  all-recursive
make[2]: Entering directory '/tmp/librb-v1.0.0-r1/librb'
Making all in include
make[3]: Entering directory '/tmp/librb-v1.0.0-r1/librb/include'
make[3]: Nothing to be done for 'all'.
make[3]: Leaving directory '/tmp/librb-v1.0.0-r1/librb/include'
Making all in rb
make[3]: Entering directory '/tmp/librb-v1.0.0-r1/librb/rb'
/bin/bash ../libtool  --tag=CC   --mode=compile gcc -DHAVE_CONFIG_H -I. -I..   -Wdate-time -D_FORTIFY_SOURCE=2 -I../include -g -O2 -fdebug-prefix-map=/tmp/librb-v1.0.0-r1/librb=. -fstack-protector-strong -Wformat -Werror=format-security -pthread -c -o librb_la-rb.lo `test -f 'rb.c' || echo './'`rb.c
libtool: compile:  gcc -DHAVE_CONFIG_H -I. -I.. -Wdate-time -D_FORTIFY_SOURCE=2 -I../include -g -O2 -fdebug-prefix-map=/tmp/librb-v1.0.0-r1/librb=. -fstack-protector-strong -Wformat -Werror=format-security -pthread -c rb.c  -fPIC -DPIC -o .libs/librb_la-rb.o
libtool: compile:  gcc -DHAVE_CONFIG_H -I. -I.. -Wdate-time -D_FORTIFY_SOURCE=2 -I../include -g -O2 -fdebug-prefix-map=/tmp/librb-v1.0.0-r1/librb=. -fstack-protector-strong -Wformat -Werror=format-security -pthread -c rb.c -o librb_la-rb.o >/dev/null 2>&1
/bin/bash ../libtool  --tag=CC   --mode=link gcc -I../include -g -O2 -fdebug-prefix-map=/tmp/librb-v1.0.0-r1/librb=. -fstack-protector-strong -Wformat -Werror=format-security -pthread -version-info 1:0:0 -Wl,-z,relro -o librb.la -rpath /usr/lib/x86_64-linux-gnu librb_la-rb.lo  
libtool: link: gcc -shared  -fPIC -DPIC  .libs/librb_la-rb.o    -g -O2 -fstack-protector-strong -pthread -Wl,-z -Wl,relro   -pthread -Wl,-soname -Wl,librb.so.1 -o .libs/librb.so.1.0.0
libtool: link: (cd ".libs" && rm -f "librb.so.1" && ln -s "librb.so.1.0.0" "librb.so.1")
libtool: link: (cd ".libs" && rm -f "librb.so" && ln -s "librb.so.1.0.0" "librb.so")
libtool: link: ar cru .libs/librb.a  librb_la-rb.o
ar: `u' modifier ignored since `D' is the default (see `U')
libtool: link: ranlib .libs/librb.a
libtool: link: ( cd ".libs" && rm -f "librb.la" && ln -s "../librb.la" "librb.la" )
make[3]: Leaving directory '/tmp/librb-v1.0.0-r1/librb/rb'
Making all in man
make[3]: Entering directory '/tmp/librb-v1.0.0-r1/librb/man'
make[3]: Nothing to be done for 'all'.
make[3]: Leaving directory '/tmp/librb-v1.0.0-r1/librb/man'
Making all in www
make[3]: Entering directory '/tmp/librb-v1.0.0-r1/librb/www'
make[3]: Nothing to be done for 'all'.
make[3]: Leaving directory '/tmp/librb-v1.0.0-r1/librb/www'
make[3]: Entering directory '/tmp/librb-v1.0.0-r1/librb'
make[3]: Leaving directory '/tmp/librb-v1.0.0-r1/librb'
make[2]: Leaving directory '/tmp/librb-v1.0.0-r1/librb'
make[1]: Leaving directory '/tmp/librb-v1.0.0-r1/librb'
	rm -f debian/*.debhelper.log
   debian/rules override_dh_auto_test
make[1]: Entering directory '/tmp/librb-v1.0.0-r1/librb'
/usr/bin/make check
make[2]: Entering directory '/tmp/librb-v1.0.0-r1/librb'
Making check in include
make[3]: Entering directory '/tmp/librb-v1.0.0-r1/librb/include'
make[3]: Nothing to be done for 'check'.
make[3]: Leaving directory '/tmp/librb-v1.0.0-r1/librb/include'
Making check in rb
make[3]: Entering directory '/tmp/librb-v1.0.0-r1/librb/rb'
/usr/bin/make  tests
make[4]: Entering directory '/tmp/librb-v1.0.0-r1/librb/rb'
gcc -DHAVE_CONFIG_H -I. -I..   -Wdate-time -D_FORTIFY_SOURCE=2 -I../include -g -O2 -fdebug-prefix-map=/tmp/librb-v1.0.0-r1/librb=. -fstack-protector-strong -Wformat -Werror=format-security -pthread -c -o tests-rb.o `test -f 'rb.c' || echo './'`rb.c
gcc -DHAVE_CONFIG_H -I. -I..   -Wdate-time -D_FORTIFY_SOURCE=2 -I../include -g -O2 -fdebug-prefix-map=/tmp/librb-v1.0.0-r1/librb=. -fstack-protector-strong -Wformat -Werror=format-security -pthread -c -o tests-tests.o `test -f 'tests.c' || echo './'`tests.c
/bin/bash ../libtool  --tag=CC   --mode=link gcc -I../include -g -O2 -fdebug-prefix-map=/tmp/librb-v1.0.0-r1/librb=. -fstack-protector-strong -Wformat -Werror=format-security -pthread  -Wl,-z,relro -o tests tests-rb.o tests-tests.o  
libtool: link: gcc -I../include -g -O2 -fdebug-prefix-map=/tmp/librb-v1.0.0-r1/librb=. -fstack-protector-strong -Wformat -Werror=format-security -pthread -Wl,-z -Wl,relro -o tests tests-rb.o tests-tests.o  -pthread
make[4]: Leaving directory '/tmp/librb-v1.0.0-r1/librb/rb'
/usr/bin/make  check-TESTS
make[4]: Entering directory '/tmp/librb-v1.0.0-r1/librb/rb'
make[5]: Entering directory '/tmp/librb-v1.0.0-r1/librb/rb'
PASS: tests 1 - multi_producers_consumers
PASS: tests 2 - multi_producers_consumers
PASS: tests 3 - multi_producers_consumers
PASS: tests 4 - multi_producers_consumers
PASS: tests 5 - multi_producers_consumers
PASS: tests 6 - multi_producers_consumers
PASS: tests 7 - multi_producers_consumers
PASS: tests 8 - multi_producers_consumers
PASS: tests 9 - multi_producers_consumers
PASS: tests 10 - multi_producers_consumers
PASS: tests 11 - multi_producers_consumers
PASS: tests 12 - multi_producers_consumers
PASS: tests 13 - multi_producers_consumers
PASS: tests 14 - multi_producers_consumers
PASS: tests 15 - multi_producers_consumers
PASS: tests 16 - multi_producers_consumers
PASS: tests 17 - multi_producers_consumers
PASS: tests 18 - multi_producers_consumers
PASS: tests 19 - multi_producers_consumers
PASS: tests 20 - multi_producers_consumers
PASS: tests 21 - multi_producers_consumers
PASS: tests 22 - multi_producers_consumers
PASS: tests 23 - multi_producers_consumers
PASS: tests 24 - multi_producers_consumers
PASS: tests 25 - multi_producers_consumers
PASS: tests 26 - multi_producers_consumers
PASS: tests 27 - multi_producers_consumers
PASS: tests 28 - multi_producers_consumers
PASS: tests 29 - multi_producers_consumers
PASS: tests 30 - multi_producers_consumers
PASS: tests 31 - multi_producers_consumers
PASS: tests 32 - multi_producers_consumers
PASS: tests 33 - multi_producers_consumers
PASS: tests 34 - multi_producers_consumers
PASS: tests 35 - multi_producers_consumers
PASS: tests 36 - multi_producers_consumers
PASS: tests 37 - multi_producers_consumers
PASS: tests 38 - multi_producers_consumers
PASS: tests 39 - multi_producers_consumers
PASS: tests 40 - multi_producers_consumers
PASS: tests 41 - multi_producers_consumers
PASS: tests 42 - multi_producers_consumers
PASS: tests 43 - multi_producers_consumers
PASS: tests 44 - multi_producers_consumers
PASS: tests 45 - multi_producers_consumers
PASS: tests 46 - multi_producers_consumers
PASS: tests 47 - multi_producers_consumers
PASS: tests 48 - multi_producers_consumers
PASS: tests 49 - multi_producers_consumers
PASS: tests 50 - multi_producers_consumers
PASS: tests 51 - multi_producers_consumers
PASS: tests 52 - multi_producers_consumers
PASS: tests 53 - multi_producers_consumers
PASS: tests 54 - multi_producers_consumers
PASS: tests 55 - multi_producers_consumers
PASS: tests 56 - multi_producers_consumers
PASS: tests 57 - multi_producers_consumers
PASS: tests 58 - multi_producers_consumers
PASS: tests 59 - multi_producers_consumers
PASS: tests 60 - multi_producers_consumers
PASS: tests 61 - multi_producers_consumers
PASS: tests 62 - multi_producers_consumers
PASS: tests 63 - multi_producers_consumers
PASS: tests 64 - multi_producers_consumers
PASS: tests 65 - multi_thread
PASS: tests 66 - single_thread
PASS: tests 67 - multi_thread
PASS: tests 68 - single_thread
PASS: tests 69 - multi_thread
PASS: tests 70 - single_thread
PASS: tests 71 - multi_thread
PASS: tests 72 - single_thread
PASS: tests 73 - multi_thread
PASS: tests 74 - single_thread
PASS: tests 75 - multi_thread
PASS: tests 76 - single_thread
PASS: tests 77 - multi_thread
PASS: tests 78 - single_thread
PASS: tests 79 - multi_thread
PASS: tests 80 - single_thread
PASS: tests 81 - multi_thread
PASS: tests 82 - single_thread
PASS: tests 83 - multi_thread
PASS: tests 84 - single_thread
PASS: tests 85 - multi_thread
PASS: tests 86 - single_thread
PASS: tests 87 - multi_thread
PASS: tests 88 - single_thread
PASS: tests 89 - multi_thread
PASS: tests 90 - single_thread
PASS: tests 91 - multi_thread
PASS: tests 92 - single_thread
PASS: tests 93 - multi_thread
PASS: tests 94 - single_thread
PASS: tests 95 - multi_thread
PASS: tests 96 - single_thread
PASS: tests 97 - multi_thread
PASS: tests 98 - single_thread
PASS: tests 99 - multi_thread
PASS: tests 100 - single_thread
PASS: tests 101 - multi_thread
PASS: tests 102 - single_thread
PASS: tests 103 - multi_thread
PASS: tests 104 - single_thread
PASS: tests 105 - multi_thread
PASS: tests 106 - single_thread
PASS: tests 107 - multi_thread
PASS: tests 108 - single_thread
PASS: tests 109 - multi_thread
PASS: tests 110 - single_thread
PASS: tests 111 - multi_thread
PASS: tests 112 - single_thread
PASS: tests 113 - multi_thread
PASS: tests 114 - single_thread
PASS: tests 115 - multi_thread
PASS: tests 116 - single_thread
PASS: tests 117 - multi_thread
PASS: tests 118 - single_thread
PASS: tests 119 - multi_thread
PASS: tests 120 - single_thread
PASS: tests 121 - multi_thread
PASS: tests 122 - single_thread
PASS: tests 123 - multi_thread
PASS: tests 124 - single_thread
PASS: tests 125 - multi_thread
PASS: tests 126 - single_thread
PASS: tests 127 - multi_thread
PASS: tests 128 - single_thread
PASS: tests 129 - multi_thread
PASS: tests 130 - single_thread
PASS: tests 131 - multi_thread
PASS: tests 132 - single_thread
PASS: tests 133 - multi_thread
PASS: tests 134 - single_thread
PASS: tests 135 - multi_thread
PASS: tests 136 - single_thread
PASS: tests 137 - multi_thread
PASS: tests 138 - single_thread
PASS: tests 139 - multi_thread
PASS: tests 140 - single_thread
PASS: tests 141 - multi_thread
PASS: tests 142 - single_thread
PASS: tests 143 - multi_thread
PASS: tests 144 - single_thread
PASS: tests 145 - multi_thread
PASS: tests 146 - single_thread
PASS: tests 147 - multi_thread
PASS: tests 148 - single_thread
PASS: tests 149 - multi_thread
PASS: tests 150 - single_thread
PASS: tests 151 - multi_thread
PASS: tests 152 - single_thread
PASS: tests 153 - multi_thread
PASS: tests 154 - single_thread
PASS: tests 155 - multi_thread
PASS: tests 156 - single_thread
PASS: tests 157 - multi_thread
PASS: tests 158 - single_thread
PASS: tests 159 - multi_thread
PASS: tests 160 - single_thread
PASS: tests 161 - multi_thread
PASS: tests 162 - single_thread
PASS: tests 163 - multi_thread
PASS: tests 164 - single_thread
PASS: tests 165 - multi_thread
PASS: tests 166 - single_thread
PASS: tests 167 - multi_thread
PASS: tests 168 - single_thread
PASS: tests 169 - multi_thread
PASS: tests 170 - single_thread
PASS: tests 171 - multi_thread
PASS: tests 172 - single_thread
PASS: tests 173 - multi_thread
PASS: tests 174 - single_thread
PASS: tests 175 - multi_thread
PASS: tests 176 - single_thread
PASS: tests 177 - multi_thread
PASS: tests 178 - single_thread
PASS: tests 179 - multi_thread
PASS: tests 180 - single_thread
PASS: tests 181 - multi_thread
PASS: tests 182 - single_thread
PASS: tests 183 - multi_thread
PASS: tests 184 - single_thread
PASS: tests 185 - multi_thread
PASS: tests 186 - single_thread
PASS: tests 187 - multi_thread
PASS: tests 188 - single_thread
PASS: tests 189 - multi_thread
PASS: tests 190 - single_thread
PASS: tests 191 - multi_thread
PASS: tests 192 - single_thread
PASS: tests 193 - multi_thread
PASS: tests 194 - single_thread
PASS: tests 195 - multi_thread
PASS: tests 196 - single_thread
PASS: tests 197 - multi_thread
PASS: tests 198 - single_thread
PASS: tests 199 - multi_thread
PASS: tests 200 - single_thread
PASS: tests 201 - multi_thread
PASS: tests 202 - single_thread
PASS: tests 203 - multi_thread
PASS: tests 204 - single_thread
PASS: tests 205 - multi_thread
PASS: tests 206 - single_thread
PASS: tests 207 - multi_thread
PASS: tests 208 - single_thread
PASS: tests 209 - multi_thread
PASS: tests 210 - single_thread
PASS: tests 211 - multi_thread
PASS: tests 212 - single_thread
PASS: tests 213 - multi_thread
PASS: tests 214 - single_thread
PASS: tests 215 - multi_thread
PASS: tests 216 - single_thread
PASS: tests 217 - multi_thread
PASS: tests 218 - single_thread
PASS: tests 219 - multi_thread
PASS: tests 220 - single_thread
PASS: tests 221 - multi_thread
PASS: tests 222 - single_thread
PASS: tests 223 - multi_thread
PASS: tests 224 - single_thread
PASS: tests 225 - multi_thread
PASS: tests 226 - single_thread
PASS: tests 227 - multi_thread
PASS: tests 228 - single_thread
PASS: tests 229 - multi_thread
PASS: tests 230 - single_thread
PASS: tests 231 - multi_thread
PASS: tests 232 - single_thread
PASS: tests 233 - multi_thread
PASS: tests 234 - single_thread
PASS: tests 235 - multi_thread
PASS: tests 236 - single_thread
PASS: tests 237 - multi_thread
PASS: tests 238 - single_thread
PASS: tests 239 - multi_thread
PASS: tests 240 - single_thread
PASS: tests 241 - multi_thread
PASS: tests 242 - single_thread
PASS: tests 243 - multi_thread
PASS: tests 244 - single_thread
PASS: tests 245 - multi_thread
PASS: tests 246 - single_thread
PASS: tests 247 - multi_thread
PASS: tests 248 - single_thread
PASS: tests 249 - multi_thread
PASS: tests 250 - single_thread
PASS: tests 251 - multi_thread
PASS: tests 252 - single_thread
PASS: tests 253 - multi_thread
PASS: tests 254 - single_thread
PASS: tests 255 - multi_thread
PASS: tests 256 - single_thread
PASS: tests 257 - multi_thread
PASS: tests 258 - single_thread
PASS: tests 259 - multi_thread
PASS: tests 260 - single_thread
PASS: tests 261 - multi_thread
PASS: tests 262 - single_thread
PASS: tests 263 - multi_thread
PASS: tests 264 - single_thread
PASS: tests 265 - multi_thread
PASS: tests 266 - single_thread
PASS: tests 267 - multi_thread
PASS: tests 268 - single_thread
PASS: tests 269 - multi_thread
PASS: tests 270 - single_thread
PASS: tests 271 - multi_thread
PASS: tests 272 - single_thread
PASS: tests 273 - multi_thread
PASS: tests 274 - single_thread
PASS: tests 275 - multi_thread
PASS: tests 276 - single_thread
PASS: tests 277 - multi_thread
PASS: tests 278 - single_thread
PASS: tests 279 - multi_thread
PASS: tests 280 - single_thread
PASS: tests 281 - multi_thread
PASS: tests 282 - single_thread
PASS: tests 283 - multi_thread
PASS: tests 284 - single_thread
PASS: tests 285 - multi_thread
PASS: tests 286 - single_thread
PASS: tests 287 - multi_thread
PASS: tests 288 - single_thread
PASS: tests 289 - multi_thread
PASS: tests 290 - single_thread
PASS: tests 291 - multi_thread
PASS: tests 292 - single_thread
PASS: tests 293 - multi_thread
PASS: tests 294 - single_thread
PASS: tests 295 - multi_thread
PASS: tests 296 - single_thread
PASS: tests 297 - multi_thread
PASS: tests 298 - single_thread
PASS: tests 299 - multi_thread
PASS: tests 300 - single_thread
PASS: tests 301 - multi_thread
PASS: tests 302 - single_thread
PASS: tests 303 - multi_thread
PASS: tests 304 - single_thread
PASS: tests 305 - multi_thread
PASS: tests 306 - single_thread
PASS: tests 307 - peeking
PASS: tests 308 - bad_count_value
PASS: tests 309 - invalid_read_write
PASS: tests 310 - multithread_flag
PASS: tests 311 - nonblocking_flag
PASS: tests 312 - singlethread_eagain
PASS: tests 313 - discard
PASS: tests 314 - count_and_space
PASS: tests 315 - einval
PASS: tests 316 - multithread_eagain
============================================================================
Testsuite summary for librb 1.0.0
============================================================================
# TOTAL: 316
# PASS:  316
# SKIP:  0
# XFAIL: 0
# FAIL:  0
# XPASS: 0
# ERROR: 0
============================================================================
make[5]: Leaving directory '/tmp/librb-v1.0.0-r1/librb/rb'
make[4]: Leaving directory '/tmp/librb-v1.0.0-r1/librb/rb'
make[3]: Leaving directory '/tmp/librb-v1.0.0-r1/librb/rb'
Making check in man
make[3]: Entering directory '/tmp/librb-v1.0.0-r1/librb/man'
make[3]: Nothing to be done for 'check'.
make[3]: Leaving directory '/tmp/librb-v1.0.0-r1/librb/man'
Making check in www
make[3]: Entering directory '/tmp/librb-v1.0.0-r1/librb/www'
make[3]: Nothing to be done for 'check'.
make[3]: Leaving directory '/tmp/librb-v1.0.0-r1/librb/www'
make[3]: Entering directory '/tmp/librb-v1.0.0-r1/librb'
make[3]: Leaving directory '/tmp/librb-v1.0.0-r1/librb'
make[2]: Leaving directory '/tmp/librb-v1.0.0-r1/librb'
make[1]: Leaving directory '/tmp/librb-v1.0.0-r1/librb'
   create-stamp debian/debhelper-build-stamp
 fakeroot debian/rules binary
dh binary --list-missing --with autoreconf
   dh_testroot -O--list-missing
   dh_prep -O--list-missing
	rm -f debian/librb1.substvars
	rm -f debian/librb1.*.debhelper
	rm -rf debian/librb1/
	rm -f debian/librb-dev.substvars
	rm -f debian/librb-dev.*.debhelper
	rm -rf debian/librb-dev/
   dh_auto_install -O--list-missing
	install -d debian/librb1
	install -d debian/librb-dev
	make -j1 install DESTDIR=/tmp/librb-v1.0.0-r1/librb/debian/tmp AM_UPDATE_INFO_DIR=no
make[1]: Entering directory '/tmp/librb-v1.0.0-r1/librb'
Making install in include
make[2]: Entering directory '/tmp/librb-v1.0.0-r1/librb/include'
make[3]: Entering directory '/tmp/librb-v1.0.0-r1/librb/include'
make[3]: Nothing to be done for 'install-exec-am'.
 /bin/mkdir -p '/tmp/librb-v1.0.0-r1/librb/debian/tmp/usr/include'
 /usr/bin/install -c -m 644 rb.h '/tmp/librb-v1.0.0-r1/librb/debian/tmp/usr/include'
make[3]: Leaving directory '/tmp/librb-v1.0.0-r1/librb/include'
make[2]: Leaving directory '/tmp/librb-v1.0.0-r1/librb/include'
Making install in rb
make[2]: Entering directory '/tmp/librb-v1.0.0-r1/librb/rb'
make[3]: Entering directory '/tmp/librb-v1.0.0-r1/librb/rb'
 /bin/mkdir -p '/tmp/librb-v1.0.0-r1/librb/debian/tmp/usr/lib/x86_64-linux-gnu'
 /bin/bash ../libtool   --mode=install /usr/bin/install -c   librb.la '/tmp/librb-v1.0.0-r1/librb/debian/tmp/usr/lib/x86_64-linux-gnu'
libtool: install: /usr/bin/install -c .libs/librb.so.1.0.0 /tmp/librb-v1.0.0-r1/librb/debian/tmp/usr/lib/x86_64-linux-gnu/librb.so.1.0.0
libtool: install: (cd /tmp/librb-v1.0.0-r1/librb/debian/tmp/usr/lib/x86_64-linux-gnu && { ln -s -f librb.so.1.0.0 librb.so.1 || { rm -f librb.so.1 && ln -s librb.so.1.0.0 librb.so.1; }; })
libtool: install: (cd /tmp/librb-v1.0.0-r1/librb/debian/tmp/usr/lib/x86_64-linux-gnu && { ln -s -f librb.so.1.0.0 librb.so || { rm -f librb.so && ln -s librb.so.1.0.0 librb.so; }; })
libtool: install: /usr/bin/install -c .libs/librb.lai /tmp/librb-v1.0.0-r1/librb/debian/tmp/usr/lib/x86_64-linux-gnu/librb.la
libtool: install: /usr/bin/install -c .libs/librb.a /tmp/librb-v1.0.0-r1/librb/debian/tmp/usr/lib/x86_64-linux-gnu/librb.a
libtool: install: chmod 644 /tmp/librb-v1.0.0-r1/librb/debian/tmp/usr/lib/x86_64-linux-gnu/librb.a
libtool: install: ranlib /tmp/librb-v1.0.0-r1/librb/debian/tmp/usr/lib/x86_64-linux-gnu/librb.a
libtool: warning: remember to run 'libtool --finish /usr/lib/x86_64-linux-gnu'
make[3]: Nothing to be done for 'install-data-am'.
make[3]: Leaving directory '/tmp/librb-v1.0.0-r1/librb/rb'
make[2]: Leaving directory '/tmp/librb-v1.0.0-r1/librb/rb'
Making install in man
make[2]: Entering directory '/tmp/librb-v1.0.0-r1/librb/man'
make[3]: Entering directory '/tmp/librb-v1.0.0-r1/librb/man'
make[3]: Nothing to be done for 'install-exec-am'.
 /bin/mkdir -p '/tmp/librb-v1.0.0-r1/librb/debian/tmp/usr/share/man/man3'
 /usr/bin/install -c -m 644 rb_clear.3 rb_count.3 rb_destroy.3 rb_discard.3 rb_new.3 rb_read.3 rb_recv.3 rb_send.3 rb_space.3 rb_version.3 rb_write.3 rb_stop.3 '/tmp/librb-v1.0.0-r1/librb/debian/tmp/usr/share/man/man3'
 /bin/mkdir -p '/tmp/librb-v1.0.0-r1/librb/debian/tmp/usr/share/man/man7'
 /usr/bin/install -c -m 644 rb_overview.7 '/tmp/librb-v1.0.0-r1/librb/debian/tmp/usr/share/man/man7'
make[3]: Leaving directory '/tmp/librb-v1.0.0-r1/librb/man'
make[2]: Leaving directory '/tmp/librb-v1.0.0-r1/librb/man'
Making install in www
make[2]: Entering directory '/tmp/librb-v1.0.0-r1/librb/www'
make[3]: Entering directory '/tmp/librb-v1.0.0-r1/librb/www'
make[3]: Nothing to be done for 'install-exec-am'.
make[3]: Nothing to be done for 'install-data-am'.
make[3]: Leaving directory '/tmp/librb-v1.0.0-r1/librb/www'
make[2]: Leaving directory '/tmp/librb-v1.0.0-r1/librb/www'
make[2]: Entering directory '/tmp/librb-v1.0.0-r1/librb'
make[3]: Entering directory '/tmp/librb-v1.0.0-r1/librb'
make[3]: Nothing to be done for 'install-exec-am'.
make[3]: Nothing to be done for 'install-data-am'.
make[3]: Leaving directory '/tmp/librb-v1.0.0-r1/librb'
make[2]: Leaving directory '/tmp/librb-v1.0.0-r1/librb'
make[1]: Leaving directory '/tmp/librb-v1.0.0-r1/librb'
   dh_install -O--list-missing
	install -d debian/librb1//usr/lib/x86_64-linux-gnu
	cp --reflink=auto -a debian/tmp/usr/lib/x86_64-linux-gnu/librb.so.1 debian/librb1//usr/lib/x86_64-linux-gnu/
	cp --reflink=auto -a debian/tmp/usr/lib/x86_64-linux-gnu/librb.so.1.0.0 debian/librb1//usr/lib/x86_64-linux-gnu/
	install -d debian/librb-dev//usr/lib/x86_64-linux-gnu
	cp --reflink=auto -a debian/tmp/usr/lib/x86_64-linux-gnu/librb.so debian/librb-dev//usr/lib/x86_64-linux-gnu/
	install -d debian/librb-dev//usr/include
	cp --reflink=auto -a debian/tmp/usr/include/rb.h debian/librb-dev//usr/include/
	install -d debian/librb-dev//usr/share/man/man3
	cp --reflink=auto -a debian/tmp/usr/share/man/man3/rb_clear.3 debian/librb-dev//usr/share/man/man3/
	cp --reflink=auto -a debian/tmp/usr/share/man/man3/rb_count.3 debian/librb-dev//usr/share/man/man3/
	cp --reflink=auto -a debian/tmp/usr/share/man/man3/rb_destroy.3 debian/librb-dev//usr/share/man/man3/
	cp --reflink=auto -a debian/tmp/usr/share/man/man3/rb_discard.3 debian/librb-dev//usr/share/man/man3/
	cp --reflink=auto -a debian/tmp/usr/share/man/man3/rb_new.3 debian/librb-dev//usr/share/man/man3/
	cp --reflink=auto -a debian/tmp/usr/share/man/man3/rb_read.3 debian/librb-dev//usr/share/man/man3/
	cp --reflink=auto -a debian/tmp/usr/share/man/man3/rb_recv.3 debian/librb-dev//usr/share/man/man3/
	cp --reflink=auto -a debian/tmp/usr/share/man/man3/rb_send.3 debian/librb-dev//usr/share/man/man3/
	cp --reflink=auto -a debian/tmp/usr/share/man/man3/rb_space.3 debian/librb-dev//usr/share/man/man3/
	cp --reflink=auto -a debian/tmp/usr/share/man/man3/rb_stop.3 debian/librb-dev//usr/share/man/man3/
	cp --reflink=auto -a debian/tmp/usr/share/man/man3/rb_version.3 debian/librb-dev//usr/share/man/man3/
	cp --reflink=auto -a debian/tmp/usr/share/man/man3/rb_write.3 debian/librb-dev//usr/share/man/man3/
	install -d debian/librb-dev//usr/share/man/man7
	cp --reflink=auto -a debian/tmp/usr/share/man/man7/rb_overview.7 debian/librb-dev//usr/share/man/man7/
dh_install: usr/lib/x86_64-linux-gnu/librb.a exists in debian/tmp but is not installed to anywhere
dh_install: usr/lib/x86_64-linux-gnu/librb.la exists in debian/tmp but is not installed to anywhere
   dh_installdocs -O--list-missing
	install -d debian/librb1/usr/share/doc/librb1
	install -p -m0644 debian/copyright debian/librb1/usr/share/doc/librb1/copyright
	install -d debian/librb-dev/usr/share/doc/librb-dev
	install -p -m0644 debian/copyright debian/librb-dev/usr/share/doc/librb-dev/copyright
   dh_installchangelogs -O--list-missing
	install -p -m0644 debian/changelog debian/librb1/usr/share/doc/librb1/changelog
	install -p -m0644 debian/changelog debian/librb-dev/usr/share/doc/librb-dev/changelog
   dh_installman -O--list-missing
	rm -f debian/librb-dev/usr/share/man/man3/rb_count.3
	ln -sf rb_space.3 debian/librb-dev/usr/share/man/man3/rb_count.3
	rm -f debian/librb-dev/usr/share/man/man3/rb_stop.3
	ln -sf rb_destroy.3 debian/librb-dev/usr/share/man/man3/rb_stop.3
	rm -f debian/librb-dev/usr/share/man/man3/rb_recv.3
	ln -sf rb_read.3 debian/librb-dev/usr/share/man/man3/rb_recv.3
	rm -f debian/librb-dev/usr/share/man/man3/rb_send.3
	ln -sf rb_write.3 debian/librb-dev/usr/share/man/man3/rb_send.3
	man --recode UTF-8 ./rb_overview\.7 > rb_overview\.7\.new
	chmod 0755 -- rb_overview.7.new
	chown 0:0 -- rb_overview.7.new
	mv -f rb_overview.7.new rb_overview.7
	man --recode UTF-8 ./rb_version\.3 > rb_version\.3\.new
	chmod 0755 -- rb_version.3.new
	chown 0:0 -- rb_version.3.new
	mv -f rb_version.3.new rb_version.3
	man --recode UTF-8 ./rb_destroy\.3 > rb_destroy\.3\.new
	chmod 0755 -- rb_destroy.3.new
	chown 0:0 -- rb_destroy.3.new
	mv -f rb_destroy.3.new rb_destroy.3
	man --recode UTF-8 ./rb_discard\.3 > rb_discard\.3\.new
	chmod 0755 -- rb_discard.3.new
	chown 0:0 -- rb_discard.3.new
	mv -f rb_discard.3.new rb_discard.3
	man --recode UTF-8 ./rb_new\.3 > rb_new\.3\.new
	chmod 0755 -- rb_new.3.new
	chown 0:0 -- rb_new.3.new
	mv -f rb_new.3.new rb_new.3
	man --recode UTF-8 ./rb_read\.3 > rb_read\.3\.new
	chmod 0755 -- rb_read.3.new
	chown 0:0 -- rb_read.3.new
	mv -f rb_read.3.new rb_read.3
	man --recode UTF-8 ./rb_space\.3 > rb_space\.3\.new
	chmod 0755 -- rb_space.3.new
	chown 0:0 -- rb_space.3.new
	mv -f rb_space.3.new rb_space.3
	man --recode UTF-8 ./rb_write\.3 > rb_write\.3\.new
	chmod 0755 -- rb_write.3.new
	chown 0:0 -- rb_write.3.new
	mv -f rb_write.3.new rb_write.3
	man --recode UTF-8 ./rb_clear\.3 > rb_clear\.3\.new
	chmod 0755 -- rb_clear.3.new
	chown 0:0 -- rb_clear.3.new
	mv -f rb_clear.3.new rb_clear.3
   dh_perl -O--list-missing
   dh_link -O--list-missing
	rm -f debian/librb1/usr/lib/x86_64-linux-gnu/librb.so.1
	ln -sf librb.so.1.0.0 debian/librb1/usr/lib/x86_64-linux-gnu/librb.so.1
	rm -f debian/librb-dev/usr/share/man/man3/rb_send.3
	ln -sf rb_write.3 debian/librb-dev/usr/share/man/man3/rb_send.3
	rm -f debian/librb-dev/usr/share/man/man3/rb_recv.3
	ln -sf rb_read.3 debian/librb-dev/usr/share/man/man3/rb_recv.3
	rm -f debian/librb-dev/usr/share/man/man3/rb_stop.3
	ln -sf rb_destroy.3 debian/librb-dev/usr/share/man/man3/rb_stop.3
	rm -f debian/librb-dev/usr/share/man/man3/rb_count.3
	ln -sf rb_space.3 debian/librb-dev/usr/share/man/man3/rb_count.3
	rm -f debian/librb-dev/usr/lib/x86_64-linux-gnu/librb.so
	ln -sf librb.so.1.0.0 debian/librb-dev/usr/lib/x86_64-linux-gnu/librb.so
   dh_strip_nondeterminism -O--list-missing
   dh_compress -O--list-missing
	cd debian/librb1
	chmod a-x usr/share/doc/librb1/changelog
	gzip -9nf usr/share/doc/librb1/changelog
	cd '/tmp/librb-v1.0.0-r1/librb'
	cd debian/librb-dev
	chmod a-x usr/share/doc/librb-dev/changelog usr/share/man/man3/rb_clear.3 usr/share/man/man3/rb_destroy.3 usr/share/man/man3/rb_discard.3 usr/share/man/man3/rb_new.3 usr/share/man/man3/rb_read.3 usr/share/man/man3/rb_space.3 usr/share/man/man3/rb_version.3 usr/share/man/man3/rb_write.3 usr/share/man/man7/rb_overview.7
	gzip -9nf usr/share/doc/librb-dev/changelog usr/share/man/man3/rb_clear.3 usr/share/man/man3/rb_destroy.3 usr/share/man/man3/rb_discard.3 usr/share/man/man3/rb_new.3 usr/share/man/man3/rb_read.3 usr/share/man/man3/rb_space.3 usr/share/man/man3/rb_version.3 usr/share/man/man3/rb_write.3 usr/share/man/man7/rb_overview.7
	cd '/tmp/librb-v1.0.0-r1/librb'
	rm -f debian/librb-dev/usr/share/man/man3/rb_count.3
	ln -sf rb_space.3.gz debian/librb-dev/usr/share/man/man3/rb_count.3.gz
	rm -f debian/librb-dev/usr/share/man/man3/rb_recv.3
	ln -sf rb_read.3.gz debian/librb-dev/usr/share/man/man3/rb_recv.3.gz
	rm -f debian/librb-dev/usr/share/man/man3/rb_stop.3
	ln -sf rb_destroy.3.gz debian/librb-dev/usr/share/man/man3/rb_stop.3.gz
	rm -f debian/librb-dev/usr/share/man/man3/rb_send.3
	ln -sf rb_write.3.gz debian/librb-dev/usr/share/man/man3/rb_send.3.gz
   dh_fixperms -O--list-missing
	find debian/librb1  -print0 2>/dev/null | xargs -0r chown --no-dereference 0:0
	find debian/librb1 ! -type l  -print0 2>/dev/null | xargs -0r chmod go=rX,u+rw,a-s
	find debian/librb1/usr/share/doc -type f  ! -regex 'debian/librb1/usr/share/doc/[^/]*/examples/.*' -print0 2>/dev/null | xargs -0r chmod 0644
	find debian/librb1/usr/share/doc -type d  -print0 2>/dev/null | xargs -0r chmod 0755
	find debian/librb1/usr/share/man -type f  -print0 2>/dev/null | xargs -0r chmod 0644
	find debian/librb1/usr/include -type f  -print0 2>/dev/null | xargs -0r chmod 0644
	find debian/librb1/usr/share/applications -type f  -print0 2>/dev/null | xargs -0r chmod 0644
	find debian/librb1/usr/lib/x86_64-linux-gnu/perl5/5.24 debian/librb1/usr/share/perl5 -type f -perm -5 -name '*.pm'  -print0 2>/dev/null | xargs -0r chmod a-X
	find debian/librb1 -perm -5 -type f \( -name '*.so.*' -o -name '*.so' -o -name '*.la' -o -name '*.a' -o -name '*.js' -o -name '*.css' -o -name '*.jpeg' -o -name '*.jpg' -o -name '*.png' -o -name '*.gif' -o -name '*.cmxs' \)  -print0 2>/dev/null | xargs -0r chmod 0644
	find debian/librb1/usr/lib -type f -name '*.ali'  -print0 2>/dev/null | xargs -0r chmod uga-w
	find debian/librb-dev  -print0 2>/dev/null | xargs -0r chown --no-dereference 0:0
	find debian/librb-dev ! -type l  -print0 2>/dev/null | xargs -0r chmod go=rX,u+rw,a-s
	find debian/librb-dev/usr/share/doc -type f  ! -regex 'debian/librb-dev/usr/share/doc/[^/]*/examples/.*' -print0 2>/dev/null | xargs -0r chmod 0644
	find debian/librb-dev/usr/share/doc -type d  -print0 2>/dev/null | xargs -0r chmod 0755
	find debian/librb-dev/usr/share/man -type f  -print0 2>/dev/null | xargs -0r chmod 0644
	find debian/librb-dev/usr/include -type f  -print0 2>/dev/null | xargs -0r chmod 0644
	find debian/librb-dev/usr/share/applications -type f  -print0 2>/dev/null | xargs -0r chmod 0644
	find debian/librb-dev/usr/lib/x86_64-linux-gnu/perl5/5.24 debian/librb-dev/usr/share/perl5 -type f -perm -5 -name '*.pm'  -print0 2>/dev/null | xargs -0r chmod a-X
	find debian/librb-dev -perm -5 -type f \( -name '*.so.*' -o -name '*.so' -o -name '*.la' -o -name '*.a' -o -name '*.js' -o -name '*.css' -o -name '*.jpeg' -o -name '*.jpg' -o -name '*.png' -o -name '*.gif' -o -name '*.cmxs' \)  -print0 2>/dev/null | xargs -0r chmod 0644
	find debian/librb-dev/usr/lib -type f -name '*.ali'  -print0 2>/dev/null | xargs -0r chmod uga-w
   dh_strip -O--list-missing
	install -d debian/.debhelper/librb1/dbgsym-root/usr/lib/debug/.build-id/dd
	objcopy --only-keep-debug --compress-debug-sections debian/librb1/usr/lib/x86_64-linux-gnu/librb.so.1.0.0 debian/.debhelper/librb1/dbgsym-root/usr/lib/debug/.build-id/dd/1c847b42186c6e3a7d61e76a7e54fadd4a3869.debug
	chmod 0644 -- debian/.debhelper/librb1/dbgsym-root/usr/lib/debug/.build-id/dd/1c847b42186c6e3a7d61e76a7e54fadd4a3869.debug
	chown 0:0 -- debian/.debhelper/librb1/dbgsym-root/usr/lib/debug/.build-id/dd/1c847b42186c6e3a7d61e76a7e54fadd4a3869.debug
	strip --remove-section=.comment --remove-section=.note --strip-unneeded debian/librb1/usr/lib/x86_64-linux-gnu/librb.so.1.0.0
	objcopy --add-gnu-debuglink debian/.debhelper/librb1/dbgsym-root/usr/lib/debug/.build-id/dd/1c847b42186c6e3a7d61e76a7e54fadd4a3869.debug debian/librb1/usr/lib/x86_64-linux-gnu/librb.so.1.0.0
	install -d debian/.debhelper/librb1/dbgsym-root/usr/share/doc
	ln -s librb1 debian/.debhelper/librb1/dbgsym-root/usr/share/doc/librb1-dbgsym
   dh_makeshlibs -O--list-missing
	rm -f debian/librb1/DEBIAN/shlibs
	install -d debian/librb1/DEBIAN
	echo 'librb 1 librb1' >>debian/librb1/DEBIAN/shlibs
	chmod 0644 -- debian/librb1/DEBIAN/shlibs
	chown 0:0 -- debian/librb1/DEBIAN/shlibs
	install -d debian/.debhelper/generated/librb1
	mv -f debian/.debhelper/generated/librb1/triggers.new debian/.debhelper/generated/librb1/triggers
	rm -f debian/librb-dev/DEBIAN/shlibs
   dh_shlibdeps -O--list-missing
	dpkg-shlibdeps -Tdebian/librb1.substvars debian/librb1/usr/lib/x86_64-linux-gnu/librb.so.1.0.0
	install -d debian/librb-dev/DEBIAN
   dh_installdeb -O--list-missing
	install -p -m0644 debian/.debhelper/generated/librb1/triggers debian/librb1/DEBIAN/triggers
   dh_gencontrol -O--list-missing
	echo misc:Depends= >> debian/librb1.substvars
	echo misc:Pre-Depends= >> debian/librb1.substvars
	install -d debian/.debhelper/librb1/dbgsym-root/DEBIAN
	dpkg-gencontrol -plibrb1 -ldebian/changelog -Tdebian/librb1.substvars -Pdebian/.debhelper/librb1/dbgsym-root -UPre-Depends -URecommends -USuggests -UEnhances -UProvides -UEssential -UConflicts -DPriority=extra -DAuto-Built-Package=debug-symbols -DPackage=librb1-dbgsym "-DDepends=librb1 (= \${binary:Version})" "-DDescription=Debug symbols for librb1" -DBuild-Ids=dd1c847b42186c6e3a7d61e76a7e54fadd4a3869 -DSection=debug -UMulti-Arch -UReplaces -UBreaks
	chmod 0644 -- debian/.debhelper/librb1/dbgsym-root/DEBIAN/control
	chown 0:0 -- debian/.debhelper/librb1/dbgsym-root/DEBIAN/control
	dpkg-gencontrol -plibrb1 -ldebian/changelog -Tdebian/librb1.substvars -Pdebian/librb1
	chmod 0644 -- debian/librb1/DEBIAN/control
	chown 0:0 -- debian/librb1/DEBIAN/control
	echo misc:Depends= >> debian/librb-dev.substvars
	echo misc:Pre-Depends= >> debian/librb-dev.substvars
	dpkg-gencontrol -plibrb-dev -ldebian/changelog -Tdebian/librb-dev.substvars -Pdebian/librb-dev
	chmod 0644 -- debian/librb-dev/DEBIAN/control
	chown 0:0 -- debian/librb-dev/DEBIAN/control
   dh_md5sums -O--list-missing
	(cd debian/librb1 >/dev/null ; find . -type f  ! -regex './DEBIAN/.*' -printf '%P\0' | LC_ALL=C sort -z | xargs -r0 md5sum | perl -pe 'if (s@^\\@@) { s/\\\\/\\/g; }' > DEBIAN/md5sums) >/dev/null
	chmod 0644 -- debian/librb1/DEBIAN/md5sums
	chown 0:0 -- debian/librb1/DEBIAN/md5sums
	(cd debian/.debhelper/librb1/dbgsym-root >/dev/null ; find . -type f ! -regex './DEBIAN/.*' -printf '%P\0' | LC_ALL=C sort -z | xargs -r0 md5sum | perl -pe 'if (s@^\\@@) { s/\\\\/\\/g; }' > DEBIAN/md5sums) >/dev/null
	chmod 0644 -- debian/.debhelper/librb1/dbgsym-root/DEBIAN/md5sums
	chown 0:0 -- debian/.debhelper/librb1/dbgsym-root/DEBIAN/md5sums
	(cd debian/librb-dev >/dev/null ; find . -type f  ! -regex './DEBIAN/.*' -printf '%P\0' | LC_ALL=C sort -z | xargs -r0 md5sum | perl -pe 'if (s@^\\@@) { s/\\\\/\\/g; }' > DEBIAN/md5sums) >/dev/null
	chmod 0644 -- debian/librb-dev/DEBIAN/md5sums
	chown 0:0 -- debian/librb-dev/DEBIAN/md5sums
   dh_builddeb -O--list-missing
	dpkg-deb -z1 -Zxz -Sextreme --build debian/.debhelper/librb1/dbgsym-root ..
dpkg-deb: building package 'librb1-dbgsym' in '../librb1-dbgsym_1.0.0_amd64.deb'.
	dpkg-deb --build debian/librb1 ..
dpkg-deb: building package 'librb1' in '../librb1_1.0.0_amd64.deb'.
	dpkg-deb --build debian/librb-dev ..
dpkg-deb: building package 'librb-dev' in '../librb-dev_1.0.0_amd64.deb'.
 dpkg-genbuildinfo
 dpkg-genchanges  >../librb_1.0.0_amd64.changes
dpkg-genchanges: info: including full source code in upload
 dpkg-source --after-build librb
dpkg-buildpackage: info: full upload; Debian-native package (full source is included)
Now running lintian...
warning: the authors of lintian do not recommend running it with root privileges!
W: librb-dev: manpage-has-bad-whatis-entry usr/share/man/man3/rb_discard.3.gz
W: librb-dev: manpage-has-errors-from-man usr/share/man/man3/rb_new.3.gz 33: warning: macro `Icount' not defined
Finished running lintian.
